
import { Link } from 'react-router-dom';
import { Facebook, Twitter, Instagram, Linkedin, Mail, Phone, MapPin } from 'lucide-react';

const Footer = () => {
  const currentYear = new Date().getFullYear();
  
  return (
    <footer className="footer mt-auto">
      <div className="container mx-auto px-4 py-12">
        <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-8">
          {/* Company Info */}
          <div className="space-y-4">
            <div className="flex items-center space-x-2">
              <div className="w-10 h-10 rounded-lg bg-gradient-to-br from-brand-red to-brand-maroon flex items-center justify-center text-white font-bold text-xl">FT</div>
              <div>
                <h3 className="font-bold text-xl">FinTap</h3>
                <p className="text-sm text-gray-400">by CIFT</p>
              </div>
            </div>
            <p className="text-sm text-gray-300">
              Next-generation AI-powered credit risk assessment platform for financial institutions.
            </p>
            <div className="flex space-x-3">
              <a href="https://facebook.com" aria-label="Facebook" className="text-gray-400 hover:text-brand-orange transition-colors">
                <Facebook size={18} />
              </a>
              <a href="https://twitter.com" aria-label="Twitter" className="text-gray-400 hover:text-brand-orange transition-colors">
                <Twitter size={18} />
              </a>
              <a href="https://instagram.com" aria-label="Instagram" className="text-gray-400 hover:text-brand-orange transition-colors">
                <Instagram size={18} />
              </a>
              <a href="https://linkedin.com" aria-label="LinkedIn" className="text-gray-400 hover:text-brand-orange transition-colors">
                <Linkedin size={18} />
              </a>
            </div>
          </div>

          {/* Quick Links */}
          <div>
            <h3 className="font-semibold text-lg mb-4 text-gray-100">Quick Links</h3>
            <ul className="space-y-2">
              <li><Link to="/" className="text-gray-400 hover:text-brand-orange transition-colors text-sm">Home</Link></li>
              <li><Link to="/assessment" className="text-gray-400 hover:text-brand-orange transition-colors text-sm">Assessment</Link></li>
              <li><Link to="/sign-in" className="text-gray-400 hover:text-brand-orange transition-colors text-sm">Sign In</Link></li>
              <li><Link to="/sign-up" className="text-gray-400 hover:text-brand-orange transition-colors text-sm">Sign Up</Link></li>
            </ul>
          </div>

          {/* Legal */}
          <div>
            <h3 className="font-semibold text-lg mb-4 text-gray-100">Legal</h3>
            <ul className="space-y-2">
              <li><Link to="/terms" className="text-gray-400 hover:text-brand-orange transition-colors text-sm">Terms of Service</Link></li>
              <li><Link to="/privacy" className="text-gray-400 hover:text-brand-orange transition-colors text-sm">Privacy Policy</Link></li>
              <li><Link to="/cookies" className="text-gray-400 hover:text-brand-orange transition-colors text-sm">Cookie Policy</Link></li>
              <li><Link to="/accessibility" className="text-gray-400 hover:text-brand-orange transition-colors text-sm">Accessibility</Link></li>
            </ul>
          </div>

          {/* Contact */}
          <div>
            <h3 className="font-semibold text-lg mb-4 text-gray-100">Contact</h3>
            <ul className="space-y-3">
              <li className="flex items-start">
                <Mail className="mr-2 h-5 w-5 text-brand-red shrink-0 mt-0.5" />
                <span className="text-gray-300 text-sm">ceo@ciftbd.com</span>
              </li>
              <li className="flex items-start">
                <Phone className="mr-2 h-5 w-5 text-brand-red shrink-0 mt-0.5" />
                <span className="text-gray-300 text-sm">+880 1754 459594</span>
              </li>
              <li className="flex items-start">
                <MapPin className="mr-2 h-5 w-5 text-brand-red shrink-0 mt-0.5" />
                <span className="text-gray-300 text-sm">CIFT Headquarters, Dhaka, Bangladesh</span>
              </li>
            </ul>
          </div>
        </div>

        <div className="border-t border-gray-800 mt-12 pt-6 flex flex-col md:flex-row justify-between items-center">
          <p className="text-sm text-gray-500 mb-4 md:mb-0">
            &copy; {currentYear} FinTap by CIFT. All rights reserved.
          </p>
          <div className="flex space-x-4">
            <a href="#" className="text-sm text-gray-500 hover:text-brand-orange">Help Center</a>
            <a href="#" className="text-sm text-gray-500 hover:text-brand-orange">Status</a>
            <a href="#" className="text-sm text-gray-500 hover:text-brand-orange">Developers</a>
          </div>
        </div>
      </div>
    </footer>
  );
};

export default Footer;
